@@ -6,8 +6,9 @@ import pytest
 
 from splitio.api.client import HttpResponse
 from splitio.api import APIException
-from splitio.engine.impressions import Manager as ImpressionsManager
-from splitio.engine.impressions import Counter
+from splitio.engine.impressions.impressions import Manager as ImpressionsManager
+from splitio.engine.impressions.manager import Counter
+from splitio.engine.impressions.strategies import StrategyOptimizedMode
 from splitio.sync.impression import ImpressionsCountSynchronizer
 from splitio.api.impressions import ImpressionsAPI
 
@@ -16,7 +17,7 @@ class ImpressionsCountSynchronizerTests(object):
     """ImpressionsCount synchronizer test cases."""
 
     def test_synchronize_impressions_counts(self, mocker):
-        manager = mocker.Mock(spec=ImpressionsManager)
+        counter = mocker.Mock(spec=Counter)
 
         counters = [
             Counter.CountPerFeature('f1', 123, 2),
@@ -25,13 +26,13 @@ class ImpressionsCountSynchronizerTests(object):
             Counter.CountPerFeature('f2', 456, 222)
         ]
 
-        manager.get_counts.return_value = counters
+        counter.pop_all.return_value = counters
         api = mocker.Mock(spec=ImpressionsAPI)
         api.flush_counters.return_value = HttpResponse(200, '')
-        impression_count_synchronizer = ImpressionsCountSynchronizer(api, manager)
+        impression_count_synchronizer = ImpressionsCountSynchronizer(api, counter)
         impression_count_synchronizer.synchronize_counters()
 
-        assert manager.get_counts.mock_calls[0] == mocker.call()
+        assert counter.pop_all.mock_calls[0] == mocker.call()
         assert api.flush_counters.mock_calls[0] == mocker.call(counters)
 
         assert len(api.flush_counters.mock_calls) == 1
